==> dde-printer_0.9.2.orig.tar.xz: dde-printer-0.9.2/src/Deamon/translations/dde-printer-helper_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="554"/>
        <source>URI and driver do not match.</source>
        <translation>URIདང་སྐུལ་བྱེད་སྙོམ་སྒྲིག་མེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="556"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>hplipསྒྲིག་འཇུག་བྱས་རྗེས་ཡང་བསྐྱར་ཁ་སྣོན་བྱེད།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="564"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>hplipསྐུལ་བྱེད་གཞན་བདམས་རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="577"/>
        <source>URI can&apos;t be empty</source>
        <translation>URIསྟོང་པ་ཡིན་མི་རུང་།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="584"/>
        <source> not found</source>
        <translation>མ་རྙེད་པ།</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="307"/>
        <source>Check printer settings</source>
        <translation>པར་འཁོར་སྒྲིག་འགོད་ཞིབ་བཤེར་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="316"/>
        <source>Checking printer settings...</source>
        <translation>པར་འཁོར་སྒྲིག་འགོད་ཞིབ་བཤེར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="319"/>
        <source>Success</source>
        <translation>ལེགས་གྲུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="329"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>པར་འཁོར་གྱི་ངོ་བོ་ཐོབ་ཐབས་མི་འདུག ནོར་བའི་རྒྱུ་མཚན་ནི།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="337"/>
        <source>%1 is disabled</source>
        <translation>%1འགོ་བསྔངས་མེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="346"/>
        <source>is not accepting jobs</source>
        <translation>ལས་འགན་དང་ལེན་མི་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="351"/>
        <source>Printer settings are ok</source>
        <translation>པར་འཁོར་གྱི་སྒྲིག་འགོད་རྒྱུན་ལྡན་རེད་འདུག</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="212"/>
        <source>Check printer connection</source>
        <translation>པར་འཁོར་གྱི་སྦྲེལ་མཐུད་རྣམ་པར་ཞིབ་བཤེར་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="224"/>
        <source>Checking printer connection...</source>
        <translation>པར་འཁོར་གྱི་སྦྲེལ་མཐུད་རྣམ་པར་ཞིབ་བཤེར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="227"/>
        <source>Success</source>
        <translation>ལེགས་གྲུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="264"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>པར་འཁོར་དང་སྦྲེལ་མ་ཐུབ། ནོར་བའི་རྒྱུ་མཚན་ནི་%1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="272"/>
        <source> is not connected, URI: </source>
        <translation>སྦྲེལ་མེད་པ། URI</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="281"/>
        <source>%1 does not exist</source>
        <translation>%1 དཀར་ཆག་མེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="290"/>
        <source>Cannot connect to the printer</source>
        <translation>པར་འཁོར་དང་སྦྲེལ་མ་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="296"/>
        <source>The connection is valid</source>
        <translation>པར་འཁོར་གྱི་སྦྲེལ་མཐུད་རྣམ་པ་རྒྱུན་ལྡན་རེད་འདུག</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="110"/>
        <source>Check CUPS server</source>
        <translation>CUPSཞབས་ཞུ་ཕྱེ་ཡོད་མེད་ཞིབ་བཤེར་བྱེད།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="116"/>
        <source>Checking CUPS server...</source>
        <translation>CUPSཞབས་ཞུ་ཞིབ་བཤེར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="118"/>
        <source>CUPS server is invalid</source>
        <translation>CUPSཞབས་ཞུ་རྒྱུན་འགལ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="123"/>
        <source>CUPS server is valid</source>
        <translation>CUPSཞབས་ཞུ་རྒྱུན་ལྡན་ཡིན་པ།</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="141"/>
        <source>Checking driver...</source>
        <translation>སྐུལ་བྱེད་ཡིག་ཆར་ཞིབ་བཤེར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="144"/>
        <source>Success</source>
        <translation>ལེགས་གྲུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="152"/>
        <source>PPD file %1 not found</source>
        <translation>PPDཡིག་ཆ་%1 རྙེད་མ་ཐུབ་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="162"/>
        <source>The driver is damaged</source>
        <translation>སྐུལ་བྱེད་ཡིག་ཆ་སྐྱོན་ཤོར་བ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="178"/>
        <source>Driver filter %1 not found</source>
        <translation>Filter %1 སྐུལ་བྱེད་རྙེད་མ་ཐུབ་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="190"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 སྒྲིག་འཇུག་བྱས་མེད། པར་འདེབས་མི་ཐུབ་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="196"/>
        <source>Driver is valid</source>
        <translation>སྐུལ་བྱེད་ཡིག་ཆ་སྐྱོན་མེད་ཆ་ཚང་བ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="202"/>
        <source>Check driver</source>
        <translation>སྐུལ་བྱེད་ཞིབ་བཤེར།</translation>
    </message>
</context>
<context>
    <name>CupsMonitor</name>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="77"/>
        <source>Queuing</source>
        <translation>གྲལ་སྒྲིག་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="78"/>
        <source>Paused</source>
        <translation>མཚམས་འཇོག</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="79"/>
        <source>Printing</source>
        <translation>པར་འདེབས་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="80"/>
        <source>Stopped</source>
        <translation>མཚམས་བཞག</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="81"/>
        <source>Canceled</source>
        <translation>འདོར་ཟིན།</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="82"/>
        <source>Error</source>
        <translation>པར་འདེབས་རྒྱུན་འགལ།</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="83"/>
        <source>Completed</source>
        <translation>ལེགས་གྲུབ་བྱུང་།</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="338"/>
        <source>%1 timed out, reason: %2</source>
        <translation>%1པར་འདེབས་དུས་ཚོད་ལས་བརྒལ་བ། རྒྱུ་མཚན་ནི་%2</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="352"/>
        <source>%1 printed successfully, please take away the paper in time!</source>
        <translation>%1པར་བཏབ་ཟིན་པས། ཤོག་ཡིག་དུས་ཐོག་ཏུ་ལེན་རོགས།</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="354"/>
        <source>%1 %2, reason: %3</source>
        <translation>%1%2 རྒྱུ་མཚན་ནི་%3</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="906"/>
        <source>EveryWhere driver</source>
        <translation>EveryWhere སྒུལ་མེད་ཇུས་གཞི།</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="371"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>སྒུལ་བྱེད་ཐག་གཅོད་བྱེད་པའི་ཇུས་གཞི་འཚོལ་རྒྱུ། %1ཕམ་པ། ནོར་འཁྲུལ་ཨང་རྟགས།%2</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="382"/>
        <source>The solution is invalid</source>
        <translation>ཞབས་ཞུ་ཆས་ཀྱི་སྒུལ་བྱེད་གཞི་གྲངས་འགྲིག་མི་འདུག</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="252"/>
        <source>is invalid</source>
        <translation>སྒྲིག་སྦྱོར་བྱེད་ཐབས་མེད།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="281"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>dbusབརྒྱུད་ནས་སྒུལ་བྱེད་སྒྲིག་སྦྱོར་བྱེད་མི་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="326"/>
        <source>Failed to install %1</source>
        <translation>%1སྒྲིག་སྦྱོར་བྱེད་མི་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>མ་རྙེད་པ།</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="372"/>
        <source>Check test page printing</source>
        <translation>ཚོད་ལྟའི་ཤོག་ངོས་པར་འདེབས་པའི་གནས་ཚུལ་ཞིབ་བཤེར་བྱ་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="426"/>
        <source>Printing test page...</source>
        <translation>ཚོད་ལྟའི་ཤོག་ངོས་པར་འདེབས་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../Common/common.cpp" line="152"/>
        <source> not found, please ask the administrator for help</source>
        <translation>དབྱེ་ཞིབ་བྱེད་ཐབས་མེད་པས། དོ་དམ་པ་དང་འབྲེལ་བ་གནང་རོགས།</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Print Manager</source>
        <translation>པར་འདེབས་དོ་དམ་ཆས།</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>པར་འདེབས་དོ་དམ་ཆས་ནི་CUPSལ་གཞི་རྟེན་པའི་པར་འདེབས་འཕྲུལ་འཁོར་དོ་དམ་བྱེད་པའི་ཡོ་བྱད་ཞིག་རེད། པར་འདེབས་འཕྲུལ་འཁོར་གྱི་དོ་དམ་དང་པར་འདེབས་ལས་འགན་དོ་དམ་སོགས་ལ་རྒྱབ་སྐྱོར་བྱེད།</translation>
    </message>
</context>
<context>
    <name>USBThread</name>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="257"/>
        <source>Configuring the printer %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="303"/>
        <source>Configuration successful. Click to view %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="307"/>
        <source>Configuration failed. Click to add the printer %1.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-printer_0.9.13.orig.tar.xz: dde-printer-0.9.13/src/Deamon/translations/dde-printer-helper_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="552"/>
        <source>URI and driver do not match.</source>
        <translation>URIདང་སྐུལ་བྱེད་སྙོམ་སྒྲིག་མེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="554"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>hplipསྒྲིག་འཇུག་བྱས་རྗེས་ཡང་བསྐྱར་ཁ་སྣོན་བྱེད།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="562"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>hplipསྐུལ་བྱེད་གཞན་བདམས་རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="575"/>
        <source>URI can&apos;t be empty</source>
        <translation>URIསྟོང་པ་ཡིན་མི་རུང་།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="582"/>
        <source> not found</source>
        <translation>མ་རྙེད་པ།</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="305"/>
        <source>Check printer settings</source>
        <translation>པར་འཁོར་སྒྲིག་འགོད་ཞིབ་བཤེར་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="314"/>
        <source>Checking printer settings...</source>
        <translation>པར་འཁོར་སྒྲིག་འགོད་ཞིབ་བཤེར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="317"/>
        <source>Success</source>
        <translation>ལེགས་གྲུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="327"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>པར་འཁོར་གྱི་ངོ་བོ་ཐོབ་ཐབས་མི་འདུག ནོར་བའི་རྒྱུ་མཚན་ནི།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="335"/>
        <source>%1 is disabled</source>
        <translation>%1འགོ་བསྔངས་མེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="344"/>
        <source>is not accepting jobs</source>
        <translation>ལས་འགན་དང་ལེན་མི་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="349"/>
        <source>Printer settings are ok</source>
        <translation>པར་འཁོར་གྱི་སྒྲིག་འགོད་རྒྱུན་ལྡན་རེད་འདུག</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="211"/>
        <source>Check printer connection</source>
        <translation>པར་འཁོར་གྱི་སྦྲེལ་མཐུད་རྣམ་པར་ཞིབ་བཤེར་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="223"/>
        <source>Checking printer connection...</source>
        <translation>པར་འཁོར་གྱི་སྦྲེལ་མཐུད་རྣམ་པར་ཞིབ་བཤེར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="226"/>
        <source>Success</source>
        <translation>ལེགས་གྲུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="263"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>པར་འཁོར་དང་སྦྲེལ་མ་ཐུབ། ནོར་བའི་རྒྱུ་མཚན་ནི་%1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="271"/>
        <source> is not connected, URI: </source>
        <translation>སྦྲེལ་མེད་པ། URI</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="280"/>
        <source>%1 does not exist</source>
        <translation>%1 དཀར་ཆག་མེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="288"/>
        <source>Cannot connect to the printer</source>
        <translation>པར་འཁོར་དང་སྦྲེལ་མ་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="294"/>
        <source>The connection is valid</source>
        <translation>པར་འཁོར་གྱི་སྦྲེལ་མཐུད་རྣམ་པ་རྒྱུན་ལྡན་རེད་འདུག</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="109"/>
        <source>Check CUPS server</source>
        <translation>CUPSཞབས་ཞུ་ཕྱེ་ཡོད་མེད་ཞིབ་བཤེར་བྱེད།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="115"/>
        <source>Checking CUPS server...</source>
        <translation>CUPSཞབས་ཞུ་ཞིབ་བཤེར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="117"/>
        <source>CUPS server is invalid</source>
        <translation>CUPSཞབས་ཞུ་རྒྱུན་འགལ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="122"/>
        <source>CUPS server is valid</source>
        <translation>CUPSཞབས་ཞུ་རྒྱུན་ལྡན་ཡིན་པ།</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="140"/>
        <source>Checking driver...</source>
        <translation>སྐུལ་བྱེད་ཡིག་ཆར་ཞིབ་བཤེར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="143"/>
        <source>Success</source>
        <translation>ལེགས་གྲུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="151"/>
        <source>PPD file %1 not found</source>
        <translation>PPDཡིག་ཆ་%1 རྙེད་མ་ཐུབ་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="161"/>
        <source>The driver is damaged</source>
        <translation>སྐུལ་བྱེད་ཡིག་ཆ་སྐྱོན་ཤོར་བ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="177"/>
        <source>Driver filter %1 not found</source>
        <translation>Filter %1 སྐུལ་བྱེད་རྙེད་མ་ཐུབ་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="189"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 སྒྲིག་འཇུག་བྱས་མེད། པར་འདེབས་མི་ཐུབ་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="195"/>
        <source>Driver is valid</source>
        <translation>སྐུལ་བྱེད་ཡིག་ཆ་སྐྱོན་མེད་ཆ་ཚང་བ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="201"/>
        <source>Check driver</source>
        <translation>སྐུལ་བྱེད་ཞིབ་བཤེར།</translation>
    </message>
</context>
<context>
    <name>CupsMonitor</name>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="77"/>
        <source>Queuing</source>
        <translation>གྲལ་སྒྲིག་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="78"/>
        <source>Paused</source>
        <translation>མཚམས་འཇོག</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="79"/>
        <source>Printing</source>
        <translation>པར་འདེབས་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="80"/>
        <source>Stopped</source>
        <translation>མཚམས་བཞག</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="81"/>
        <source>Canceled</source>
        <translation>འདོར་ཟིན།</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="82"/>
        <source>Error</source>
        <translation>པར་འདེབས་རྒྱུན་འགལ།</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="83"/>
        <source>Completed</source>
        <translation>ལེགས་གྲུབ་བྱུང་།</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="338"/>
        <source>%1 timed out, reason: %2</source>
        <translation>%1པར་འདེབས་དུས་ཚོད་ལས་བརྒལ་བ། རྒྱུ་མཚན་ནི་%2</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="352"/>
        <source>%1 has been sent to the printer, please take away the paper in time!</source>
        <translation>%1དཔར་འཁོར་དུ་བསྐུར་ཟིན་པས། ཤོག་ཡིག་དུས་ཐོག་ཏུ་ལེན་རོགས།</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="354"/>
        <source>%1 %2, reason: %3</source>
        <translation>%1%2 རྒྱུ་མཚན་ནི་%3</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1022"/>
        <source>EveryWhere driver</source>
        <translation>EveryWhere སྒུལ་མེད་ཇུས་གཞི།</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="372"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>སྒུལ་བྱེད་ཐག་གཅོད་བྱེད་པའི་ཇུས་གཞི་འཚོལ་རྒྱུ། %1ཕམ་པ། ནོར་འཁྲུལ་ཨང་རྟགས།%2</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="383"/>
        <source>The solution is invalid</source>
        <translation>ཞབས་ཞུ་ཆས་ཀྱི་སྒུལ་བྱེད་གཞི་གྲངས་འགྲིག་མི་འདུག</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="250"/>
        <source>is invalid</source>
        <translation>སྒྲིག་སྦྱོར་བྱེད་ཐབས་མེད།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="279"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>dbusབརྒྱུད་ནས་སྒུལ་བྱེད་སྒྲིག་སྦྱོར་བྱེད་མི་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="324"/>
        <source>Failed to install %1</source>
        <translation>%1སྒྲིག་སྦྱོར་བྱེད་མི་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>མ་རྙེད་པ།</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="370"/>
        <source>Check test page printing</source>
        <translation>ཚོད་ལྟའི་ཤོག་ངོས་པར་འདེབས་པའི་གནས་ཚུལ་ཞིབ་བཤེར་བྱ་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="424"/>
        <source>Printing test page...</source>
        <translation>ཚོད་ལྟའི་ཤོག་ངོས་པར་འདེབས་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../Common/common.cpp" line="154"/>
        <source> not found, please ask the administrator for help</source>
        <translation>དབྱེ་ཞིབ་བྱེད་ཐབས་མེད་པས། དོ་དམ་པ་དང་འབྲེལ་བ་གནང་རོགས།</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Print Manager</source>
        <translation>པར་འདེབས་དོ་དམ་ཆས།</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>པར་འདེབས་དོ་དམ་ཆས་ནི་CUPSལ་གཞི་རྟེན་པའི་པར་འདེབས་འཕྲུལ་འཁོར་དོ་དམ་བྱེད་པའི་ཡོ་བྱད་ཞིག་རེད། པར་འདེབས་འཕྲུལ་འཁོར་གྱི་དོ་དམ་དང་པར་འདེབས་ལས་འགན་དོ་དམ་སོགས་ལ་རྒྱབ་སྐྱོར་བྱེད།</translation>
    </message>
</context>
<context>
    <name>USBThread</name>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="256"/>
        <source>Configuring the printer %1 ...</source>
        <translation>པར་འཁོར་%1སྡེབ་སྒྲིག་བྱེད་བཞིན་ཡོད་པས། སྒུག་རོགས། </translation>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="302"/>
        <source>Configuration successful. Click to view %1.</source>
        <translation>སྡེབ་སྒྲིག་བྱས་ཟིན། མནན་ནས་%1ལྟ་བཤེར་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="306"/>
        <source>Configuration failed. Click to add the printer %1.</source>
        <translation>སྡེག་སྒྲིག་བྱེད་མ་ཐུབ་པས། ལག་སྒུལ་གྱིས་%1ཁ་སྣོན་བྱེད་པ།</translation>
    </message>
</context>
</TS>
